Introduction
============

.. include:: includes/all.rst

The ``debops-contrib.btrfs`` Ansible role allows you manage your Btrfs.
Currently the role supports management of Btrfs subvolumes.
More can be implemented as needed.

Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.1.3``. To install it, run::

    ansible-galaxy install debops-contrib.btrfs


..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
